#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : redis
# @Time         : 2024/3/26 11:21
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
from meutils.pipe import *

from redis import Redis, ConnectionPool
from redis.asyncio import Redis as AsyncRedis, ConnectionPool as AsyncConnectionPool

from meutils.request_utils.ip import get_myip

REDIS_NAME = "REDIS_URL" if get_myip() else "OVERSEAS_REDIS_URL"  # 自动判断海外

kwargs = dict(
    # --- 关键配置：保活与自动恢复 ---

    # [最大连接数] 防止高并发下创建过多连接把 Redis 撑爆
    # 异步环境下，协程数可能远大于连接数，这个限制很有必要
    max_connections=128,

    # [健康检查] 关键参数！
    # 获取连接时，如果连接空闲超过 30 秒，发送 PING 检查。
    # 如果 PING 失败，自动回收坏连接并创建新连接。
    health_check_interval=25,

    # [TCP 保活] 操作系统层面的 Keepalive，防止僵尸连接
    socket_keepalive=True,

    # [连接超时] 建立 TCP 连接的最大等待时间
    socket_connect_timeout=5,

    # [读写超时] (可选) 防止网络卡死导致协程一直挂起
    socket_timeout=2.0,

    # 断线重连
    retry_on_timeout=True,
    # retry_on_error=[ConnectionError, TimeoutError],
    # retry=Retry(ExponentialBackoff(cap=2, base=0.1), 3),  # 最多重试3次
)

if REDIS_URL := os.getenv(REDIS_NAME) or os.getenv("REDIS_URL"):  # 默认国内
    logger.debug(REDIS_URL)

    pool = ConnectionPool.from_url(REDIS_URL, **kwargs)
    redis_client = Redis.from_pool(pool)

    async_pool = AsyncConnectionPool.from_url(REDIS_URL, **kwargs)
    redis_aclient = AsyncRedis.from_pool(async_pool)
    # redis_client = Redis.from_url(REDIS_URL, **kwargs)
    # redis_aclient = AsyncRedis.from_url(REDIS_URL, **kwargs)

else:
    redis_client = Redis(**kwargs)  # decode_responses=True
    redis_aclient = AsyncRedis(**kwargs)


async def sadd(name, *values, ttl: int = 0):
    await redis_aclient.sadd(name, *values)

    if ttl:
        await redis_aclient.expire(name, ttl)


if __name__ == '__main__':
    # from meutils.pipe import *

    # print(arun(redis_aclient.get("")))
    # print(redis_client.lrange("https://api.moonshot.cn/v1",0, -1))

    # print(redis_client.lrange("https://api.deepseek.com/v1",0, -1))
    # print(redis_client.exists("https://api.deepseek.com/v1"))

    # print(type(redis_aclient.get("test")))

    # print(redis_client.delete("https://api.deepseek.com/v1"))
    feishu_url = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=79272d"
    feishu_url = "https://xchatllm.feishu.cn/sheets/GYCHsvI4qhnDPNtI4VPcdw2knEd?sheet=EYgZ8c"

    # with timer():
    #     print(feishu_url in redis_client)
    #
    # with timer():
    #     redis_client.exists(feishu_url)
    # with timer():
    #     print(redis_client.llen(feishu_url))

    # print(redis_client.set('a', 'xx21212'))
    # print(redis_client.set('b', b'xx21212'))
    #
    # print(redis_client.get('a'))
    # print(redis_client.get('b'))

    #
    # print(redis_client.type(feishu))
    # _ = redis_client.lrange(feishu, 0, -1)
    # print(len(eval(_)))

    task_id = "celery-task-meta-ca94c602-a2cc-4db5-afe4-763f30df8a18"

    # arun(redis_aclient.get('celery-task-meta-72d59447-1f88-4727-8067-8244c2268faa'))
    #
    # arun(redis_aclient.select(1))

    # async def main():
    #     r = await redis_aclient.select(1)
    #     return await redis_aclient.get(task_id)
    #
    #
    # arun(main())

    # async def main():
    #     return await redis_aclient.lpop("redis_key")

    # arun(main())

    # r = redis_client.sadd('set1', 'a', 'b', 'c')
    # r = redis_client.sadd('set1', 'd')
    # k="meutils.config_utils.lark_utils.commonaget_spreadsheet_values()[(＇feishu_url＇, ＇https://xchatllm.feishu.cn/sheets/GYCHsvI4qhnDPNtI4VPcdw2knEd?sheet=Gvm9dt＇), (＇to_dataframe＇, True)]	"
    # redis_client.delete(k)
    # print(redis_client.get('test'))

    # print(redis_client.delete("k"))

    # print(type(redis_client.type('pods').decode()))
    # print(redis_client.get('xxsadasd').decode())

    # redis_client.set("pods", "10.219.11.231 114.66.55.228")

    # for i in ["cgt-20260227134919-t68t8",]
    from meutils.apis.oneapi.tasks import get_tasks

    cookie = "ve_doc_history=84458%2C82379%2C6737%2C6269%2C6256%2C85128%2C86081%2C6348%2C85621%2C6260;_qimei_fingerprint=efbb885a22f7d4e5589008c28bc8e7ba;hasUserBehavior=1;monitor_huoshan_web_id=7467761534115284489;referrer_title=%E6%A8%A1%E5%9E%8B%E8%B4%B9%E7%94%A8--%E6%89%A3%E5%AD%90-%E7%81%AB%E5%B1%B1%E5%BC%95%E6%93%8E;AccountID=2119872855;user_locale=zh;signin_i18next=zh;monitor_session_id_flag=1;monitor_traceid_base_cookie=1526;volcengineLoginMethod=pwd;_tea_utm_cache_3569={%22utm_source%22:%22coopensrc%22%2C%22utm_medium%22:%22github%22%2C%22utm_campaign%22:%22doubao%22%2C%22utm_term%22:%22project%22%2C%22utm_content%22:%22aidrawio%22};volcfe-uuid=0701f6f2-a611-4599-a2fc-57cb015ff828;userInfo=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhY2NfaSI6MjExOTg3Mjg1NSwiYXVkIjpbImNvbnNvbGUudm9sY2VuZ2luZS5jb20iXSwiZXhwIjoxNzc0Nzc2MTg5LCJpIjoiZWU4OGExY2QxM2JkMTFmMTg4ODIzNDM2YWMxMjAwYjEiLCJpZF9uIjoiOUdxIzNuI1VrNTgiLCJtc2ciOm51bGwsInBpZCI6ImZhYmRhNzEzLTQ2ZDItNGYwYy1hNGM2LWRkNTA4Njk0MTFiOSIsInNzX24iOiI5R3EjM24jVWs1OCIsInQiOiJBY2NvdW50IiwidG9waWMiOiJzaWduaW5fdXNlcl9pbmZvIiwidmVyc2lvbiI6InYxIiwiemlwIjoiIn0.fqSdE3Upi0nqi1o3Oau5qbZRaEzrDYOaX1cxC2nV53Zbdant-vCEIKX8PlnVE3uzs1RnX0uAKvq0oQNajnPSMWK08fBN6NthVxmpPnbgIeZ4lDG_V6EW1yC95qXCoefZN_4t-5M_fozxZaVRXqYSdXWLkmrnqHOzbWxx4TAn6qZHNdT364_Dt7226vGF1aamKxEE3JbGSSlCDSbZxY73zQDJphATulUgf4wYaleREqw5M2fgAErxA8uRZ3o0STnAr_jBE-RwWR1fo_PU_Ky5JO8_YmsrTYQAaF240DNtvxreB_X6iNqWuW44hjMJbLSXtraa2cXJtL1iou_s2Rn9hw;__tea_cache_tokens_3569={%22web_id%22:%227467761534115284489%22%2C%22user_unique_id%22:%227467761534115284489%22%2C%22timestamp%22:1772184191039%2C%22_type_%22:%22default%22};volc-design-locale=zh;_qimei_h38=94cee221b20e31b701a412450300000ce19c18;finance-hub-sdk-lang=zh;p_c_check=1;volc_platform_clear_user_locale=1;__spti=11_000JnXNrWATPtPrMwlQ3ilQxfn2UtC;__sptiho=0B11_000JnXNrWATPtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC;_qimei_i_1=76d3738b9109058ec395ff62598426e3f6bca3f1130a0783b68b2d582593206c616364c03980b1ddde83ccd2;_qimei_i_3=57ca79d3970c52d9c497aa625d8027e5a6bcf0f71a5b04d4e0872b502092276d32633f973989e28184b1;_qimei_uuid42=19c180a1723100cab20e31b701a4124555c551b916;_tea_utm_cache_520918={%22utm_source%22:%22coopensrc%22%2C%22utm_medium%22:%22github%22%2C%22utm_campaign%22:%22doubao%22%2C%22utm_term%22:%22project%22%2C%22utm_content%22:%22aidrawio%22};csrfToken=552a2771ef2bd2065a71909f68ae3f95;digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzIzNTY5ODksImlhdCI6MTc3MjE4NDE4OSwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiJmYWJkYTcxMy00NmQyLTRmMGMtYTRjNi1kZDUwODY5NDExYjkiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNTJMeFM4eE5GZUsyZEM5VU5zNVREczAydFpCNGNxVDFMSnZDWHhBcFpNN0Y3cGljbkYrYVZ5SncvZEdyVCt4U3lDcVZ3SnExMkpMemMzUHo4N3lRcFFBQkFBRC8vMzgwRkh4YUFBQUEiLCJuYW1lIjoiOUdxIzNuI1VrNTgiLCJzdWIiOiIyMTE5ODcyODU1IiwidG9waWMiOiJzaWduaW5fY3JlZGVudGlhbCIsInRybiI6InRybjppYW06OjIxMTk4NzI4NTU6cm9vdCIsInZlcnNpb24iOiJ2MSIsInppcCI6Imd6aXAifQ.IjYSlUVBHTMm2DblZD1M3n9X2TASeut2U-1eCva9kyeoOv0vUuxPK6x_SDw4ykGM0Ozs2lYRYSGIvS1-TRPpImCGjrkwGBIh45zWep3cAfsba36ssnE9CMjDBY8MMuu5VR0BTzIYL6RYnm2hOSvG-FQ2a4JjofqUdCXbB-hLteA635p6PpIZ9qUr4nHK-y2RexukOP4TmvIU57MeCw_15RbLi18oZQGbELNtOYP1Yhfc6pedkrCoZumdS1GPMxQVE7hTg6PlxxhATU_NsGbaSedh8MZbHZfb41z-at41E2AF1sp9PeYkTroB1iftaUf0rD1Xbwzq5k_Cwqbiad_3aQ;gfkadpd=3569,42874|520918,36088;i18next=zh;isIntranet=0;login_scene=11;monitor_session_id=9081223115845153279;monitor_utm=%257B%2522utm_campaign%2522%253A%2522doubao%2522%252C%2522utm_content%2522%253A%2522aidrawio%2522%252C%2522utm_medium%2522%253A%2522github%2522%252C%2522utm_source%2522%253A%2522coopensrc%2522%252C%2522utm_term%2522%253A%2522project%2522%257D;s_v_web_id=verify_mlxcna5b_OPnHmJyI_isi9_4Wph_AE1g_IryXIJgAqHFs;top_region=;vcloudWebId=0d8e34f9-2a27-4f3b-a86a-10cb562dbf67;VOLCFE_im_uuid=1771893239908012284"

    REDIS_URL = "redis://:chatfirechatfire@110.42.51.201:6379"
    async_pool = AsyncConnectionPool.from_url(REDIS_URL, **kwargs)
    _redis_aclient = AsyncRedis.from_pool(async_pool)

    async def main():
        # ids = await get_tasks("", channel_id="21464", status="UNFINISHED", return_ids=True)
        ids = ["s86datc4ndrmt0cwpb7ba7xycm", "h412gwj6nhrmt0cwp9arz3579m"]
        print(ids)

        for i in ids:
            # redis_client.set(i, cookie)
            _ = await _redis_aclient.get(i)
            await redis_aclient.set(i, _, ex=10000)


    # arun(main())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : run_delay_tasks
# @Time         : 2026/2/16 13:39
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
import asyncio

from meutils.pipe import *

from meutils.db.redis_db import redis_aclient
from meutils.apis.volcengine_apis import videos_nx
from meutils.schemas.video_types import SoraVideoRequest, Video

from meutils.apis.videos.videos import OpenAIVideos  # todo

from meutils.apis.oneapi.tasks import get_tasks

base_url = 'delay'


async def create(api_key: Optional[str] = None, task_ids: Optional[list] = None):
    task_ids = task_ids or await get_tasks(
        platform="",
        channel_id="21496",
        status="UNFINISHED",
        return_ids=True,
        end_timestamp=int(time.time())
    )
    # for task_id in task_ids:
    #     if remote_task_id := await redis_aclient.get(f"remote:{task_id}"):
    #         remote_task_id = remote_task_id.decode()
    #         if not remote_task_id.startswith("cgt-"):
    #             await redis_aclient.delete(f"remote:{task_id}")

    task_ids = [
                   task_id for task_id in task_ids
                   if task_id.startswith("delay::")
                      and not await redis_aclient.get(f"remote:{task_id}")
                      and not await redis_aclient.get(f"response:{task_id}")
               ][::-1]

    logger.debug(f"任务数量: {len(task_ids)}")

    if not api_key: return task_ids

    async def func(task_id):
        if (request := await redis_aclient.get(f"request:{task_id}")):
            request = SoraVideoRequest.model_validate_json(request)

            # 创建任务
            # if any(i in str(e) for i in ["NotLogin", "QuotaExceeded"]):
            try:
                video = await videos_nx.Tasks(api_key).create(request)
                await redis_aclient.set(f"remote:{task_id}", video.id, ex=7 * 24 * 3600)
                logger.debug("###############")

            except Exception as e:
                if any(i in str(e) for i in ["BLOCK", "ReqTextExistRisk"]):
                    logger.debug(e)
                    video = Video(id=task_id, status="failed")
                    await redis_aclient.set(f"response:{task_id}", video.model_dump_json(exclude_none=True), ex=3600)

                else:
                    return task_id

    return await asyncio.gather(*map(func, task_ids))

    # to_do_tasks = []
    # for task_id in task_ids:
    #     if (request := await redis_aclient.get(f"request:{task_id}")):
    #         request = SoraVideoRequest.model_validate_json(request)
    #
    #         # 创建任务
    #         # if any(i in str(e) for i in ["NotLogin", "QuotaExceeded"]):
    #         try:
    #             video = await videos_nx.Tasks(api_key).create(request)
    #             await redis_aclient.set(f"remote:{task_id}", video.id, ex=7 * 24 * 3600)
    #             logger.debug("###############")
    #
    #         except Exception as e:
    #             if any(i in str(e) for i in ["BLOCK", "ReqTextExistRisk"]):
    #                 logger.debug(e)
    #                 video = Video(id=task_id, status="failed")
    #                 await redis_aclient.set(f"response:{task_id}", video.model_dump_json(exclude_none=True), ex=3600)
    #
    #             else:
    #                 to_do_tasks.append(task_id)
    #         # logger.debug(video)
    #
    # return to_do_tasks


async def get(task_ids, api_key: Optional[str] = None):
    task_ids = task_ids or await get_tasks(
        platform="",
        channel_id="21496",
        status="UNFINISHED",
        return_ids=True,
        end_timestamp=int(time.time())
    )

    task_ids = [task_id for task_id in task_ids if task_id.startswith("delay::")]
    for task_id in task_ids:
        if remote_task_id := await redis_aclient.get(f"remote:{task_id}"):
            remote_task_id = remote_task_id.decode()
            if not await redis_aclient.get(f"response:{task_id}"):

                video = await videos_nx.Tasks(api_key).get(remote_task_id)
                # logger.debug(video)
                if video.status in ["completed", "failed"]:  # 监听 写入 redis
                    await redis_aclient.set(
                        f"response:{task_id}",
                        video.model_dump_json(exclude_none=True),
                        ex=7 * 24 * 3600
                    )
                    logger.debug(f"任务已完成: {video}")
    # else:
    #     video = Video(id=task_id, status="failed")
    #     await redis_aclient.set(f"response:{task_id}", video.model_dump_json(exclude_none=True), ex=3600)


if __name__ == '__main__':
    api_key = None

    api_key = "volcfe-uuid=ecb48834-bc65-4cd1-9483-2f45d914cf50; monitor_huoshan_web_id=2413297586969042111; monitor_session_id_flag=1; vcloudWebId=b26f990b-dbd1-4473-bf63-e2db81b38a44; i18next=zh; volc-design-locale=zh; top_region=; connect.sid=s%3A74499cfb-5d70-4d34-9365-f2afd60cfc65.ysxjsRtHgkaNrB%2B%2FkAXN6s%2Fmratwj2065EhKVpYt8%2Fc; volc_platform_clear_user_locale=1; p_c_check=1; user_locale=zh; isIntranet=0; s_v_web_id=verify_mllmewgy_x9XzU70l_lWgG_4uOx_8pdW_oiGDAFwMrL22; VOLCFE_im_uuid=1771031476307323127; login_scene=11; volcengineLoginMethod=pwd; finance-hub-sdk-lang=zh; gfkadpd=3569,42874|520918,36088; __spti=11_000J3dA/BwYPtPrMwlQ3ilQxfn2UtC; __sptiho=1611_000J3dA/BwYPtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC; __spti=11_000J3dA/BwYPtPrMwlQ3ilQxfn2UtC; __sptiho=1611_000J3dA/BwYPtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC; monitor_session_id=0835711907192284696; verify_mllmewgy_x9XzU70l_lWgG_4uOx_8pdW_oiGDAFwMrL22=1; monitor_traceid_base_cookie=10; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0Mjk1MzAsImlhdCI6MTc3MTI1NjczMCwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiJlOTUyNmU3Yy03MDlhLTRmNTgtOWVkOC0wODNlMmJmMDI5ZDAiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXlNVEcybFBqeDdjd1pOb1ZaMzgrY1lSUHk1MkozVEU3T0w4MHJFWmkrN09RbmRpbHhFeU5ENDJlZDNjL203SG8rWmNXemp1M0tvY1dsNWY3SlNtQnp0TmlTODNOejgvTzhjQ2tEQkFBQS8vK0pPbllQY1FBQUFBPT0iLCJuYW1lIjoiNDIxM-aJi-acuueUqOaItyNVc3V3T2MiLCJzdWIiOiIyMTE5MzI0NDM5IiwidG9waWMiOiJzaWduaW5fY3JlZGVudGlhbCIsInRybiI6InRybjppYW06OjIxMTkzMjQ0Mzk6cm9vdCIsInZlcnNpb24iOiJ2MSIsInppcCI6Imd6aXAifQ.iPJOgaAwgmuTFWWtyTxbLMpGtj5CJWOUVqiI7oSfIgYoe_red2iW-KLVWkZXx8upRaEN7XN7PQ4WYKsxBk53-TFkXu7ca9TJAU_1jBx1KvPkQS9eHNvQmkFHVj2R4BvC1g8yMI4qsESqGOJ1jo-9eUMWTqbZXJZ1WVDa0ulMSVL4xoKCy1Cv3X7XJdg8nH3z1HGMZsVEUOtXK9lD53HvkRu4KkQLjf0cFosHMByk9c5qOEUItyyBz13TbTcZk-pc6Ra_riMedELBaFvhmHJTuiJHmj-I-jUcqvEm0MESurrmhk7jWoyzwlS8Cj9M-qI9in_PLBM42EONIrA_SFHMAA; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0Mjk1MzAsImlhdCI6MTc3MTI1NjczMCwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiJlOTUyNmU3Yy03MDlhLTRmNTgtOWVkOC0wODNlMmJmMDI5ZDAiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXlNVEcybFBqeDdjd1pOb1ZaMzgrY1lSUHk1MkozVEU3T0w4MHJFWmkrN09RbmRpbHhFeU5ENDJlZDNjL203SG8rWmNXemp1M0tvY1dsNWY3SlNtQnp0TmlTODNOejgvTzhjQ2tEQkFBQS8vK0pPbllQY1FBQUFBPT0iLCJuYW1lIjoiNDIxM-aJi-acuueUqOaItyNVc3V3T2MiLCJzdWIiOiIyMTE5MzI0NDM5IiwidG9waWMiOiJzaWduaW5fY3JlZGVudGlhbCIsInRybiI6InRybjppYW06OjIxMTkzMjQ0Mzk6cm9vdCIsInZlcnNpb24iOiJ2MSIsInppcCI6Imd6aXAifQ.iPJOgaAwgmuTFWWtyTxbLMpGtj5CJWOUVqiI7oSfIgYoe_red2iW-KLVWkZXx8upRaEN7XN7PQ4WYKsxBk53-TFkXu7ca9TJAU_1jBx1KvPkQS9eHNvQmkFHVj2R4BvC1g8yMI4qsESqGOJ1jo-9eUMWTqbZXJZ1WVDa0ulMSVL4xoKCy1Cv3X7XJdg8nH3z1HGMZsVEUOtXK9lD53HvkRu4KkQLjf0cFosHMByk9c5qOEUItyyBz13TbTcZk-pc6Ra_riMedELBaFvhmHJTuiJHmj-I-jUcqvEm0MESurrmhk7jWoyzwlS8Cj9M-qI9in_PLBM42EONIrA_SFHMAA; AccountID=2119324439; AccountID=2119324439; userInfo=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhY2NfaSI6MjExOTMyNDQzOSwiYXVkIjpbImNvbnNvbGUudm9sY2VuZ2luZS5jb20iXSwiZXhwIjoxNzczODQ4NzMwLCJpIjoiODViOTIxODQwYjRlMTFmMThhZmMzNDM2YWMxMjAxNGQiLCJpZF9uIjoiNDIxM-aJi-acuueUqOaItyNVc3V3T2MiLCJtc2ciOm51bGwsInBpZCI6ImU5NTI2ZTdjLTcwOWEtNGY1OC05ZWQ4LTA4M2UyYmYwMjlkMCIsInNzX24iOiI0MjEz5omL5py655So5oi3I1VzdXdPYyIsInQiOiJBY2NvdW50IiwidG9waWMiOiJzaWduaW5fdXNlcl9pbmZvIiwidmVyc2lvbiI6InYxIiwiemlwIjoiIn0.NS3_uLpOfNmBkRZq2WbIAy2D-7OF_v0n47Nd2DBWUVVy-ga-N03L8wK7eY3SBHgarUNUFtOWA8jx9ZXlbTrjLFw0AA0fHOv9ivW6AafHxy_x4EfwjkkjAxmZc87AGnt_5anW1NovAOFLwYaz69SvQnsTlXmAv0l_OPr6h_OuA62QNV6jUELGHvFJWIHEPiOsM1FoAcwrgbQBkJ5ixejVlWp4fSK3vrAoN0as3-O2VglCrtQHQ_fezxo1BtJcP0Dy2SMLsVDAIAN7qySo4laJDZKrpu44b3Meu6DSVbQ7dE4kqR_PrISZJHwr3vq-JbVZ17ZCELdTLb3pmiIzarIB9Q; csrfToken=e477d6d8641d349e9780c1655ca36524; csrfToken=e477d6d8641d349e9780c1655ca36524; monitor_tracing_cookie=[]; user_locale=zh; __tea_cache_tokens_3569={%22web_id%22:%227606522229002061354%22%2C%22user_unique_id%22:%227606522229002061354%22%2C%22timestamp%22:1771256741305%2C%22_type_%22:%22default%22}"


    # api_key = "volc_platform_clear_user_locale=1; p_c_check=1; vcloudWebId=5ac5cdc6-6a9c-49c9-8b0f-e6840fe2e14c; user_locale=zh; monitor_huoshan_web_id=2156107059694425912; monitor_session_id_flag=1; volc-design-locale=zh; isIntranet=0; VOLCFE_im_uuid=1771031618404202823; login_scene=11; volcengineLoginMethod=pwd; i18next=zh; s_v_web_id=verify_mllmiki8_J8jHHCcX_185R_4y9E_BrYF_sAEVozZz9j8T; finance-hub-sdk-lang=zh; gfkadpd=3569,42874|520918,36088; monitor_session_id=1500547101600265693; monitor_traceid_base_cookie=4; verify_mllmiki8_J8jHHCcX_185R_4y9E_BrYF_sAEVozZz9j8T=1; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0Mjk2MTYsImlhdCI6MTc3MTI1NjgxNiwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiI3YjVkZDAxZS1hY2YyLTQxM2ItOGYwMC02M2JmMTRkZmM5NjQiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXlNYmMwbEhqNC9jd1pOb1VQSUZMSW40dmRNVGs1dnpTdlJPRDdpcE9mMktYRVRTMk5qSjkxZGorYnMrdjVsQlhQT3JZck8vdW5aaWNHSzRITjBXSkx6cy9OemMvendxVU1FQUFBLy8vTlI5RjZjUUFBQUE9PSIsIm5hbWUiOiI1OTIz5omL5py655So5oi3I0NPZWthUyIsInN1YiI6IjIxMTkzMjQ3OTEiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyNDc5MTpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.Z23tOtJWqClakqAeKICmoWlzpX-UB2yEGTmzQg5Lf5ZdSqC4hKc1SmQR5H2EsT7V0C-MHyw7bCfbTBs6v7SF4tFzAbYbr8xGoOFsKx7ngzopyUO8Az9KfB3uSe_DGkIL8atiF03cLgmJ7pOCYEzk3wpdCXh7Hz8zfhQGHmEncMVzhG7_B6ejPzl-aSRi_jkOOC5lPg5LzKpW1ffkUCk8HoHAky1okof9z3ekZ8cciSwi2qMaw7P2Sv5C9xlcWXehHRZGFGDJ_id6RyPRG778bl29ANUZ8_7qAn4WQYANWV_qJQjK7ksOiNJnyNpTuZS_gFlv7zd9Ow8QcLi5nCPALw; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0Mjk2MTYsImlhdCI6MTc3MTI1NjgxNiwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiI3YjVkZDAxZS1hY2YyLTQxM2ItOGYwMC02M2JmMTRkZmM5NjQiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXlNYmMwbEhqNC9jd1pOb1VQSUZMSW40dmRNVGs1dnpTdlJPRDdpcE9mMktYRVRTMk5qSjkxZGorYnMrdjVsQlhQT3JZck8vdW5aaWNHSzRITjBXSkx6cy9OemMvendxVU1FQUFBLy8vTlI5RjZjUUFBQUE9PSIsIm5hbWUiOiI1OTIz5omL5py655So5oi3I0NPZWthUyIsInN1YiI6IjIxMTkzMjQ3OTEiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyNDc5MTpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.Z23tOtJWqClakqAeKICmoWlzpX-UB2yEGTmzQg5Lf5ZdSqC4hKc1SmQR5H2EsT7V0C-MHyw7bCfbTBs6v7SF4tFzAbYbr8xGoOFsKx7ngzopyUO8Az9KfB3uSe_DGkIL8atiF03cLgmJ7pOCYEzk3wpdCXh7Hz8zfhQGHmEncMVzhG7_B6ejPzl-aSRi_jkOOC5lPg5LzKpW1ffkUCk8HoHAky1okof9z3ekZ8cciSwi2qMaw7P2Sv5C9xlcWXehHRZGFGDJ_id6RyPRG778bl29ANUZ8_7qAn4WQYANWV_qJQjK7ksOiNJnyNpTuZS_gFlv7zd9Ow8QcLi5nCPALw; AccountID=2119324791; AccountID=2119324791; userInfo=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhY2NfaSI6MjExOTMyNDc5MSwiYXVkIjpbImNvbnNvbGUudm9sY2VuZ2luZS5jb20iXSwiZXhwIjoxNzczODQ4ODE2LCJpIjoiYjkwNGJiMTkwYjRlMTFmMTgzZGMzNDM2YWMxMjAwZjUiLCJpZF9uIjoiNTkyM-aJi-acuueUqOaItyNDT2VrYVMiLCJtc2ciOm51bGwsInBpZCI6IjdiNWRkMDFlLWFjZjItNDEzYi04ZjAwLTYzYmYxNGRmYzk2NCIsInNzX24iOiI1OTIz5omL5py655So5oi3I0NPZWthUyIsInQiOiJBY2NvdW50IiwidG9waWMiOiJzaWduaW5fdXNlcl9pbmZvIiwidmVyc2lvbiI6InYxIiwiemlwIjoiIn0.dIhcEOZLW51twJvIvXIFj3zDg6oRXlP67NjJxXCXkG7HkemVbb-5I6MiPyCnvlWop-TbhV8qheIEIAAQjWF0GJLRAZIZV2Yi34WFZKxPNucf9PSX2CIEtss7YwcukM0__ED7Bl1MUiUsX9GIMvVTGmZvJk9N4vy82LImf0an2zFurAP-I6WUwrU2imRprFBg8G8S0il1muJs1JoQxEyG6ChkHI1ElhdwXSGBDfr69Spvba3-VVqvbi3UHscu21BZhSFBJ41Orr_YoRoHBTTp9SRAHLWBGQg5mm5jl4BAJyTSJFVzvSoddmm0QPn8arYXmbV5nf4kxxXXhsm1tDwhYg; csrfToken=09b680210c3a10fa705e2bd9239e1436; csrfToken=09b680210c3a10fa705e2bd9239e1436; monitor_tracing_cookie=[]; user_locale=zh; __tea_cache_tokens_3569={%22web_id%22:%227606522748715107846%22%2C%22user_unique_id%22:%227606522748715107846%22%2C%22timestamp%22:1771256828644%2C%22_type_%22:%22default%22}"
    # api_key = "vcloudWebId=628549cd-c3d3-4cb8-936e-1539cee70c5a; monitor_huoshan_web_id=1935614982602037754; monitor_session_id_flag=1; connect.sid=s%3Af8e672eb-e208-489f-8e0c-9a777c81136a.ARdtNAOSZ0LqN1l%2FJ7UvQy7QqPiMkqiVDF2OK2Ug2CE; i18next=zh; volc-design-locale=zh; volc_platform_clear_user_locale=1; p_c_check=1; user_locale=zh; VOLCFE_im_uuid=1770961291284332747; login_scene=11; volcengineLoginMethod=pwd; s_v_web_id=verify_mlkgnbq9_5AbTkXNC_EYAi_4bTQ_9qnK_aJ8hRAcPggyM; finance-hub-sdk-lang=zh; gfkadpd=3569,42874|520918,36088; monitor_session_id=9034571070391286370; isIntranet=0; monitor_traceid_base_cookie=5; verify_mlkgnbq9_5AbTkXNC_EYAi_4bTQ_9qnK_aJ8hRAcPggyM=1; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0Mjk4NjAsImlhdCI6MTc3MTI1NzA2MCwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiI2MmFjZjI1MS00ZDQ3LTRhMmQtOTJmYi02OTM3ODc0YWM5NWUiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXlOVEkza0xqKzg4d1pOb1VuSUZMSW40dmRNVGs1dnpTdlJPRGFtcE9mMktYRWpjME5USjUxZGorYnMrdjVsQlhQT3JZck8xZUVWWG1YS0lITjBXSkx6cy9OemMvendxVU1FQUFBLy8vaFNVQThjUUFBQUE9PSIsIm5hbWUiOiIzNzA05omL5py655So5oi3I0N4VnpLdCIsInN1YiI6IjIxMTkzMjUyNzAiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyNTI3MDpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.VavaZEMcWuwxsYnoCXuo4mNMiVBavAofefQQjwmHWSyftQu3gjXy64ETDnNQzWX47C27k93-Bsq-21pkxl2HEi8fz3JumotsPSYFUUw2EXuVKMfElev8bFsQAtcWHhvnNaJ_FCTRCm9aEmBkVUyBWUbd5WR9FnIUGKjPUARLcTc0KJbmLOcXbvqx2_e7gEq910Wa6qCQN6SyxfLkjFzmXiHIOknNoNQt2Nhg9sIrU8FxfxZJApAiIZSfLARafP7KRJHlcoFg26s8gSYrqr1OLgA0KmHmB2PstS8N26cB9Q8cotzj1UnEegT1RX4EaVfvsw6TNbksdH0a0_wTNYfYTg; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0Mjk4NjAsImlhdCI6MTc3MTI1NzA2MCwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiI2MmFjZjI1MS00ZDQ3LTRhMmQtOTJmYi02OTM3ODc0YWM5NWUiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXlOVEkza0xqKzg4d1pOb1VuSUZMSW40dmRNVGs1dnpTdlJPRGFtcE9mMktYRWpjME5USjUxZGorYnMrdjVsQlhQT3JZck8xZUVWWG1YS0lITjBXSkx6cy9OemMvendxVU1FQUFBLy8vaFNVQThjUUFBQUE9PSIsIm5hbWUiOiIzNzA05omL5py655So5oi3I0N4VnpLdCIsInN1YiI6IjIxMTkzMjUyNzAiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyNTI3MDpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.VavaZEMcWuwxsYnoCXuo4mNMiVBavAofefQQjwmHWSyftQu3gjXy64ETDnNQzWX47C27k93-Bsq-21pkxl2HEi8fz3JumotsPSYFUUw2EXuVKMfElev8bFsQAtcWHhvnNaJ_FCTRCm9aEmBkVUyBWUbd5WR9FnIUGKjPUARLcTc0KJbmLOcXbvqx2_e7gEq910Wa6qCQN6SyxfLkjFzmXiHIOknNoNQt2Nhg9sIrU8FxfxZJApAiIZSfLARafP7KRJHlcoFg26s8gSYrqr1OLgA0KmHmB2PstS8N26cB9Q8cotzj1UnEegT1RX4EaVfvsw6TNbksdH0a0_wTNYfYTg; AccountID=2119325270; AccountID=2119325270; userInfo=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhY2NfaSI6MjExOTMyNTI3MCwiYXVkIjpbImNvbnNvbGUudm9sY2VuZ2luZS5jb20iXSwiZXhwIjoxNzczODQ5MDYwLCJpIjoiNGE5MzdhNjIwYjRmMTFmMTlhZjEzNDM2YWMxMjAwM2YiLCJpZF9uIjoiMzcwNOaJi-acuueUqOaItyNDeFZ6S3QiLCJtc2ciOm51bGwsInBpZCI6IjYyYWNmMjUxLTRkNDctNGEyZC05MmZiLTY5Mzc4NzRhYzk1ZSIsInNzX24iOiIzNzA05omL5py655So5oi3I0N4VnpLdCIsInQiOiJBY2NvdW50IiwidG9waWMiOiJzaWduaW5fdXNlcl9pbmZvIiwidmVyc2lvbiI6InYxIiwiemlwIjoiIn0.hJpHBQKkJsa6sa77lbfIjiD2wjqiAmSs7CgNqKR03lqWqfP5Sbzswmra6vbGHm4V4Al6ULT4j4ZmjGfdVww3T4dKSgrbAPDMcceU4fUdADTXD-hdnxkr4Zq4mYh5qnPqu0EcwbEEvUoR-pgNsR-hhjAtEjyJPKFv8RyAHQPLYXXczKFVTonDg55ni9CZsx0pBBrrk3vywv3AKr07T6biFsspDE5aojJlprzpawFMxd4HStyaLlvpCyt2sCV8WgiDo6ie9RLilf_eu7p_WMlpdH-l7eunD8_Jb4ceHH-3n2UxR6RreGmewtSxwrnL2Q2Gc7Pmr_pimWqp19LFJXN4Bw; csrfToken=648cdbafd5f7387c110dbec4732d7209; csrfToken=648cdbafd5f7387c110dbec4732d7209; monitor_tracing_cookie=[]; user_locale=zh; __tea_cache_tokens_3569={%22web_id%22:%227606220745165375022%22%2C%22user_unique_id%22:%227606220745165375022%22%2C%22timestamp%22:1771257067716%2C%22_type_%22:%22default%22}"
    # api_key = "volc_platform_clear_user_locale=1; p_c_check=1; vcloudWebId=4a0f785f-9b21-4ec6-ab71-8c08e7e5b297; user_locale=zh; monitor_huoshan_web_id=4267817678782828514; monitor_session_id_flag=1; volc-design-locale=zh; VOLCFE_im_uuid=1770961772150983699; login_scene=11; volcengineLoginMethod=pwd; i18next=zh; s_v_web_id=verify_mlkgx8y9_m2YZoKXC_Gawq_4sjQ_A9bP_5A8OWr8zaZ61; finance-hub-sdk-lang=zh; __spti=11_000J3daoWLQPtPrMwlQ3ilQxfn2UtC; __sptiho=5011_000J3daoWLQPtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC; __spti=11_000J3daoWLQPtPrMwlQ3ilQxfn2UtC; __sptiho=5011_000J3daoWLQPtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC; isIntranet=0; gfkadpd=3569,42874|520918,36088; monitor_session_id=3652664239756113362; monitor_traceid_base_cookie=4; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0MzAwMzEsImlhdCI6MTc3MTI1NzIzMSwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiJmMTM3ODM4Ni01MmY3LTQxYmQtODlmOC1hOTExOGU0NjQ1ZWQiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXl0VFEwbG1qL2ZlWU1tMEkvaUJUeTUySjNURTdPTDgwckViaTU4ZVFuZGlseFN6Tmp3MmVkM2MvbTdIbytaY1d6anUzS1BtR1ZLVDZKU21CenROaVM4M056OC9POGNDa0RCQUFBLy85cnFNYXVjUUFBQUE9PSIsIm5hbWUiOiI5NjMx5omL5py655So5oi3I0xWeWRMYSIsInN1YiI6IjIxMTkzMjU5MTMiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyNTkxMzpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.bpQKPgaroNzEbf40kRnwxi3jaQ5hmWAHx6A-8-eGYSkgBzcpfCKpo_Mn8hnByEa2mP68-29fyiM9sjEAM_r7F4p2EKiY_c5ltYlp1ZsXID0WXuVHdzgyHG0rbmkl-JXIa7HyDslWe89cosZxXMuwFlBoSgd9ywQ9hCTULgLDpS2lU2Q7j-eArn6DN8S0etBY4UCVS-dwAcxnkzlgtZz-yYi8_x-Ai55VmWE-fLvXIUXFnGqlzuGwEZrNaRMqMrnhjFyAZj-Tsnz38AeqHBIamLYumA6m8PYO4HbUISBwkcaBZZkhhU0nCrnruDb-XeTxDT_o_SrfPuapYsQSQXnoaw; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0MzAwMzEsImlhdCI6MTc3MTI1NzIzMSwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiJmMTM3ODM4Ni01MmY3LTQxYmQtODlmOC1hOTExOGU0NjQ1ZWQiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXl0VFEwbG1qL2ZlWU1tMEkvaUJUeTUySjNURTdPTDgwckViaTU4ZVFuZGlseFN6Tmp3MmVkM2MvbTdIbytaY1d6anUzS1BtR1ZLVDZKU21CenROaVM4M056OC9POGNDa0RCQUFBLy85cnFNYXVjUUFBQUE9PSIsIm5hbWUiOiI5NjMx5omL5py655So5oi3I0xWeWRMYSIsInN1YiI6IjIxMTkzMjU5MTMiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyNTkxMzpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.bpQKPgaroNzEbf40kRnwxi3jaQ5hmWAHx6A-8-eGYSkgBzcpfCKpo_Mn8hnByEa2mP68-29fyiM9sjEAM_r7F4p2EKiY_c5ltYlp1ZsXID0WXuVHdzgyHG0rbmkl-JXIa7HyDslWe89cosZxXMuwFlBoSgd9ywQ9hCTULgLDpS2lU2Q7j-eArn6DN8S0etBY4UCVS-dwAcxnkzlgtZz-yYi8_x-Ai55VmWE-fLvXIUXFnGqlzuGwEZrNaRMqMrnhjFyAZj-Tsnz38AeqHBIamLYumA6m8PYO4HbUISBwkcaBZZkhhU0nCrnruDb-XeTxDT_o_SrfPuapYsQSQXnoaw; AccountID=2119325913; AccountID=2119325913; userInfo=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhY2NfaSI6MjExOTMyNTkxMywiYXVkIjpbImNvbnNvbGUudm9sY2VuZ2luZS5jb20iXSwiZXhwIjoxNzczODQ5MjMxLCJpIjoiYjBhMGE0ZDEwYjRmMTFmMTljZjQzNDM2YWMxMjAwNjEiLCJpZF9uIjoiOTYzMeaJi-acuueUqOaItyNMVnlkTGEiLCJtc2ciOm51bGwsInBpZCI6ImYxMzc4Mzg2LTUyZjctNDFiZC04OWY4LWE5MTE4ZTQ2NDVlZCIsInNzX24iOiI5NjMx5omL5py655So5oi3I0xWeWRMYSIsInQiOiJBY2NvdW50IiwidG9waWMiOiJzaWduaW5fdXNlcl9pbmZvIiwidmVyc2lvbiI6InYxIiwiemlwIjoiIn0.LnDT9LCct_APr4VIb8-iaB_MRFdspCqnKI-HAhGsrWXqA2YiCssfvQpdfTt-2KcE4YNnhiM99MDo1oMo1dLMIYxwC_7RuPySNxX9lTYE9kea-ri88RUcvq2KKzVjh_g4XECjlZHXnMm49d8tzQwrJWqFX1EWTs1Gk58z_tC7XEicvX5ArhmC63kdc5WHx_UqmDhP9IhQjQrkFFVf0nKw8S53Wd7nwuNavSgf_069i9uRDA94-jcKr2keRkhjRM5KNTjrdgiYhgCj54D0-oRLfV53rCHk5MgnXmVs-hiTJJCX2wutZ-CQWYO0E6l2vV99tg5sVwI4SmdipCL4YbRaXg; csrfToken=f85cfb20e65c0ba3e515de8393932707; csrfToken=f85cfb20e65c0ba3e515de8393932707; monitor_tracing_cookie=[]; user_locale=zh; __tea_cache_tokens_3569={%22web_id%22:%227606222790610716202%22%2C%22user_unique_id%22:%227606222790610716202%22%2C%22timestamp%22:1771257242604%2C%22_type_%22:%22default%22}"
    # api_key = "ve_doc_history=82379%2C6269%2C6256%2C85128%2C86081%2C6348%2C85621%2C6260;_qimei_fingerprint=b246a945bf5dc2bf3cdfc8a907820bc8;hasUserBehavior=1;monitor_huoshan_web_id=7467761534115284489;referrer_title=;AccountID=2119323462;user_locale=zh;signin_i18next=zh;monitor_session_id_flag=1;monitor_traceid_base_cookie=1455;volcengineLoginMethod=pwd;_tea_utm_cache_3569={%22utm_source%22:%22coopensrc%22%2C%22utm_medium%22:%22github%22%2C%22utm_campaign%22:%22doubao%22%2C%22utm_term%22:%22project%22%2C%22utm_content%22:%22aidrawio%22};volcfe-uuid=0701f6f2-a611-4599-a2fc-57cb015ff828;userInfo=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhY2NfaSI6MjExOTMyMzQ2MiwiYXVkIjpbImNvbnNvbGUudm9sY2VuZ2luZS5jb20iXSwiZXhwIjoxNzczODQyMTkxLCJpIjoiNGM5ZTkxNDUwYjNmMTFmMTg4OTAzNDM2YWMxMjAwNDMiLCJpZF9uIjoiMTgwNeaJi-acuueUqOaItyN2SHZLd3oiLCJtc2ciOm51bGwsInBpZCI6IjYzNWZkZGVjLTM3YmQtNDQwYi04NTJiLThkYWE2ZTAyNTA3ZSIsInNzX24iOiIxODA15omL5py655So5oi3I3ZIdkt3eiIsInQiOiJBY2NvdW50IiwidG9waWMiOiJzaWduaW5fdXNlcl9pbmZvIiwidmVyc2lvbiI6InYxIiwiemlwIjoiIn0.HbpE4H4zyczkac3RkDkchueEekB0scfAjz9pP0YR0mHpzzfq2K60ifY4KSFnbGcMRvu5cJxO9GvEo3Ez3l5ItIZaXzrb6heAsFy-1UjunRU-Zt5J-IeJkman6wtQZZTgXSmxzFltbRz83zm8rfcSLJ3zyPkbEFmREUTgps0wNch-v2lw3nnGV-96UorvpCLX559nunov7FIHeYvvyeE86vn5uiJ7ozfLvk9UbwjtMmKNGizkcbWVOp1AwrvSQsyrzSN-HcEY79awrb0PPB7epcIGxnQ8csps1SkNswFLmpyFMwCvRsL8PHulJie02uLMNcwlB9jqPvU4E0imseENfQ;__tea_cache_tokens_3569={%22web_id%22:%227467761534115284489%22%2C%22user_unique_id%22:%227467761534115284489%22%2C%22timestamp%22:1771289842741%2C%22_type_%22:%22default%22};volc-design-locale=zh;_qimei_h38=94cee221b20e31b701a412450300000ce19c18;finance-hub-sdk-lang=zh;p_c_check=1;volc_platform_clear_user_locale=1;__spti=11_000JnXNrWATPtPrMwlQ3ilQxfn2UtC;__sptiho=0B11_000JnXNrWATPtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC;_qimei_i_1=71c52e8b9109058ec395ff62598426e3f6bca3f1130a0783b68b2d582593206c616364c03980b1ddde8dc3ef;_qimei_i_3=57ca79d3970c52d9c497aa625d8027e5a6bcf0f71a5b04d4e0872b502092276d32633f973989e28184b1;_qimei_uuid42=19c180a1723100cab20e31b701a4124555c551b916;_tea_utm_cache_520918={%22utm_source%22:%22coopensrc%22%2C%22utm_medium%22:%22github%22%2C%22utm_campaign%22:%22doubao%22%2C%22utm_term%22:%22project%22%2C%22utm_content%22:%22aidrawio%22};csrfToken=488c4774c2a6b35a5b821131eea75c6f;digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0MjI5OTEsImlhdCI6MTc3MTI1MDE5MSwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiI2MzVmZGRlYy0zN2JkLTQ0MGItODUyYi04ZGFhNmUwMjUwN2UiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXlOakV6a21nNmN1WU1tOElFRUNua3o4WHVtSnljWDVwWEluQnMzc2xQN0ZMaWhoWUdwczg2dTUvTjJmVjh5b3BuSGR1Vnl6ekt2TXVybE1EbWFMRWw1K2ZtNXVkNTRWSUdDQUFBLy8rc0EyeUJjUUFBQUE9PSIsIm5hbWUiOiIxODA15omL5py655So5oi3I3ZIdkt3eiIsInN1YiI6IjIxMTkzMjM0NjIiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyMzQ2Mjpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.VL-El689HVU3a1mYsWrxKVTxRPtb5VXL182FT8Ix7993lrGDZ3zrgESiJQXezVBj0pe07TIjBNqyp8XylkrPOw-ZQWoOPZ6mhqdpvbRDCVWOc14YEOhtWDLnkjif376tk1cpJNX4qXHazBhSa4VC1ugb8f07lCmu3vNe6hKesJ6pwNzzd43L8aS3jmv-OPRicut4AesX7emMiANghiwl4Fy-KpEuwAz6zLHVHN5kx94zjLZ89KaRMrppKVHK7zbMmCcA75zEpRubVrtrJOObqKQ5jv1SFUhMd8Jhj5_YkDG9-tLxCZ-8sg5c0nwaxHPxfd1qVpHeo-vdFPT5U9Vv-A;gfkadpd=3569,42874|520918,36088;i18next=zh;isIntranet=0;login_scene=11;monitor_session_id=4832342797404320553;monitor_tracing_cookie=[];monitor_utm=%257B%2522utm_campaign%2522%253A%2522doubao%2522%252C%2522utm_content%2522%253A%2522aidrawio%2522%252C%2522utm_medium%2522%253A%2522github%2522%252C%2522utm_source%2522%253A%2522coopensrc%2522%252C%2522utm_term%2522%253A%2522project%2522%257D;s_v_web_id=verify_mjjfj194_6wx9uxHT_RbvK_42dT_BQQF_Am4VHcR3e6qJ;top_region=;user_locale=zh;vcloudWebId=0d8e34f9-2a27-4f3b-a86a-10cb562dbf67;VOLCFE_im_uuid=1771247302981950646"
    # api_key = "monitor_huoshan_web_id=5580802690475581165; user_locale=zh; i18next=zh; volcfe-uuid=3638eba7-a4ed-40f3-976e-aade7b4913cf; hasUserBehavior=1; iaas_global_region=cn-beijing; connect.sid=s%3A46e3c0e7-20a2-4155-94fe-b3bce9edb860.nGJw45VefU8pAZ0%2BCE2eTFCLztzlVbmTQifs0O3e6Ck; vcloudWebId=404de0e8-1e9d-4786-ba76-187feb018352; monitor_session_id_flag=1; volc-design-locale=zh; signin_i18next=zh; finance-hub-sdk-lang=zh; top_region=; p_c_check=1; s_v_web_id=verify_mjqg5k9s_WbrSrTd8_T1XG_46c8_9Bu4_3MbAyFhknxHb; __spti=11_000JnIKZEO2PtPrMwlQ3ilQxfn2UtC; __sptiho=4D11_000JnIKZEO2PtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC; __spti=11_000JnIKZEO2PtPrMwlQ3ilQxfn2UtC; __sptiho=4D11_000JnIKZEO2PtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC; volc_platform_clear_user_locale=1; ve_doc_history=82379%2C6269; VOLCFE_im_uuid=1771059509799536691; login_scene=11; volcengineLoginMethod=pwd; gfkadpd=3569,42874|520918,36088; referrer_title=Seedance%202.0%20&%20Seedream%205.0%20%E5%85%8D%E8%B4%B9%E4%BD%93%E9%AA%8C%20-%20%E7%81%AB%E5%B1%B1%E5%BC%95%E6%93%8E%20AI%20%E4%BD%93%E9%AA%8C%E4%B8%AD%E5%BF%83; isIntranet=0; monitor_session_id=9775581074374001270; monitor_traceid_base_cookie=34; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0NjI3NjIsImlhdCI6MTc3MTI4OTk2MiwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiI0NzkxYjcwZi01MWQwLTQ5YjMtODUyYS1iYmQyZDNhZjg1YzciLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXl0YkEwbDdqNzY5d1pOb1ZYSUZMSW40dmRNVGs1dnpTdlJPRGt4cE9mMktYRURRek5UWjkxZGorYnMrdjVsQlhQT3JZck80WVVlR2RYS29ITjBXSkx6cy9OemMvendxVU1FQUFBLy84MlNUQVNjUUFBQUE9PSIsIm5hbWUiOiIwMTc15omL5py655So5oi3I0FUcEtreSIsInN1YiI6IjIxMTkzMjU4OTciLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyNTg5Nzpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.BLmPyCY8F953BJX_Hh9PC2k0XhbWW_rQm4QNsMCfdfz77yjpcb0gROtPNxbh6TC5ODn7h1jkr128fRa6OC3RiTgsjj6mLxKpS2ddHROjK0z48i_rCJX8WLOI8MXqmD5L00wmn9RmrnL58CIAkgyTHUVmPJgSbqRzCc_xgUr_FhOY0iFpupIzbRYPww_MPdEszhmhANNylkmEwmXqBGHq2IrkwRWI8LVJwQ2Hww86IGj2Zzoaqm8a4USpIAC0WuR4ibPrLFCTrq6pVLQQCXdcwJ43uJkLO1tRJldQ5tDN6StUBFLXzeMYlkv5HON94lQOQGs0c2S0FBJ3JIZuSu2U-g; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0NjI3NjIsImlhdCI6MTc3MTI4OTk2MiwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiI0NzkxYjcwZi01MWQwLTQ5YjMtODUyYS1iYmQyZDNhZjg1YzciLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXl0YkEwbDdqNzY5d1pOb1ZYSUZMSW40dmRNVGs1dnpTdlJPRGt4cE9mMktYRURRek5UWjkxZGorYnMrdjVsQlhQT3JZck80WVVlR2RYS29ITjBXSkx6cy9OemMvendxVU1FQUFBLy84MlNUQVNjUUFBQUE9PSIsIm5hbWUiOiIwMTc15omL5py655So5oi3I0FUcEtreSIsInN1YiI6IjIxMTkzMjU4OTciLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyNTg5Nzpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.BLmPyCY8F953BJX_Hh9PC2k0XhbWW_rQm4QNsMCfdfz77yjpcb0gROtPNxbh6TC5ODn7h1jkr128fRa6OC3RiTgsjj6mLxKpS2ddHROjK0z48i_rCJX8WLOI8MXqmD5L00wmn9RmrnL58CIAkgyTHUVmPJgSbqRzCc_xgUr_FhOY0iFpupIzbRYPww_MPdEszhmhANNylkmEwmXqBGHq2IrkwRWI8LVJwQ2Hww86IGj2Zzoaqm8a4USpIAC0WuR4ibPrLFCTrq6pVLQQCXdcwJ43uJkLO1tRJldQ5tDN6StUBFLXzeMYlkv5HON94lQOQGs0c2S0FBJ3JIZuSu2U-g; AccountID=2119325897; AccountID=2119325897; userInfo=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhY2NfaSI6MjExOTMyNTg5NywiYXVkIjpbImNvbnNvbGUudm9sY2VuZ2luZS5jb20iXSwiZXhwIjoxNzczODgxOTYyLCJpIjoiZTViNTY2YjIwYjliMTFmMThiZTkzNDM2YWMxMjAwYWQiLCJpZF9uIjoiMDE3NeaJi-acuueUqOaItyNBVHBLa3kiLCJtc2ciOm51bGwsInBpZCI6IjQ3OTFiNzBmLTUxZDAtNDliMy04NTJhLWJiZDJkM2FmODVjNyIsInNzX24iOiIwMTc15omL5py655So5oi3I0FUcEtreSIsInQiOiJBY2NvdW50IiwidG9waWMiOiJzaWduaW5fdXNlcl9pbmZvIiwidmVyc2lvbiI6InYxIiwiemlwIjoiIn0.YtvBrwjzhMAX3zDJIhtL0-Y_eEbyezgFobrgeTJLHz_xmg8Wm7PBZIOcLMSbOEzSfLGouVbtyzjcf56Aq2YK_UCpaUQyWe1pP7_9zlMHqv36F2w730FLPB4-AoY2wVJgu-uECidKOgz1QIb8yKgpI8q8r_Zl1IochjTAHgbuqdKW36jaobyqnDLrR2SFduEQ0epWXkNPYu3Kc2m6ZZOg3qiCDqhgebgIxPZ0oV1z8thLjV3heE3bvQfxkESCb3zTiGuaAeHU4hAkj2MVzBoVBI9CSoVaFqARGs7BBg-ZN7yDYJtph8JyxgneHj3NqNqHymLgEznBYEd9UZsbSQojPQ; csrfToken=8ef478bc60abf134159e4dd1efcacfbb; csrfToken=8ef478bc60abf134159e4dd1efcacfbb; __tea_cache_tokens_3569={%22web_id%22:%227584046438867830326%22%2C%22user_unique_id%22:%227584046438867830326%22%2C%22timestamp%22:1771289964077%2C%22_type_%22:%22default%22}"
    # api_key = "user_locale=zh; monitor_huoshan_web_id=3304318277473854027; monitor_session_id_flag=1; volcfe-uuid=348a8e82-b962-4178-a6a3-7b8458ed8baf; p_c_check=1; __spti=11_000JnI19p9xPtPrMwlQ3ilQxfn2UtC; __sptiho=5D11_000JnI19p9xPtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC; __spti=11_000JnI19p9xPtPrMwlQ3ilQxfn2UtC; __sptiho=5D11_000JnI19p9xPtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC; signin_i18next=zh; volc_platform_clear_user_locale=1; vcloudWebId=a7abb4af-2cbe-46e3-936c-7595f8699e41; volc-design-locale=zh; s_v_web_id=verify_mkgduwzu_ncEFpZ07_rmmj_4BQd_8WPb_EOsEG4csLG12; finance-hub-sdk-lang=zh; i18next=zh; top_region=; VOLCFE_im_uuid=1770780881526957892; login_scene=11; volcengineLoginMethod=pwd; ve_doc_history=82379; referrer_title=; hasUserBehavior=1; isIntranet=0; gfkadpd=3569,42874|520918,36088; monitor_traceid_base_cookie=347; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0MjEyMjYsImlhdCI6MTc3MTI0ODQyNiwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiIzOTEwZDlmNS1jMGI2LTRlOTktODgwNC04ZTMyYTk3ZWE1YTYiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXlOckkwbEZpeTdjd1pOb1ZWSUZMSW40dmRNVGs1dnpTdlJHRDIzSk9mMktYRWpReE1EWjUxZGorYnMrdjVsQlhQT3JZcjUyYzUrd2VVS29ITjBXSkx6cy9OemMvendxVU1FQUFBLy8rbzljOXBjUUFBQUE9PSIsIm5hbWUiOiIyMDUw5omL5py655So5oi3I29qQ09QdSIsInN1YiI6IjIxMTkzMjMyOTEiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyMzI5MTpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.F0sCBL1PLROGexvZzc3swpKviazcoU-AUmZLJ0WE7cu8LjI7--QLcBftsytmocmDfs_eEW6M5_dBDNzjAnjGOYtyknEuEUmZvzNBBqFLilSIQuog1DiguKOy73cR_Z-uLK-CjG7P6Xqc7n_m-BzmM1bUiodMm3DOgWQZ_bz1taCo5juSoI8dUZPX6u1kMsbQhy7oym1iiOyjUOXqSVReVC0xmXcWAfSS_jfzyRsWRWS5uCwgt4dZtz_4mSg2UpO5IPcg9YJdp3WS33a8D730f2P0gmBuI8NOaRpunngAurRukt3Yu7o719_9IHj5uEMDZjZxDeYr_e20uExAS_uK4A; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0MjEyMjYsImlhdCI6MTc3MTI0ODQyNiwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiIzOTEwZDlmNS1jMGI2LTRlOTktODgwNC04ZTMyYTk3ZWE1YTYiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXlOckkwbEZpeTdjd1pOb1ZWSUZMSW40dmRNVGs1dnpTdlJHRDIzSk9mMktYRWpReE1EWjUxZGorYnMrdjVsQlhQT3JZcjUyYzUrd2VVS29ITjBXSkx6cy9OemMvendxVU1FQUFBLy8rbzljOXBjUUFBQUE9PSIsIm5hbWUiOiIyMDUw5omL5py655So5oi3I29qQ09QdSIsInN1YiI6IjIxMTkzMjMyOTEiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyMzI5MTpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.F0sCBL1PLROGexvZzc3swpKviazcoU-AUmZLJ0WE7cu8LjI7--QLcBftsytmocmDfs_eEW6M5_dBDNzjAnjGOYtyknEuEUmZvzNBBqFLilSIQuog1DiguKOy73cR_Z-uLK-CjG7P6Xqc7n_m-BzmM1bUiodMm3DOgWQZ_bz1taCo5juSoI8dUZPX6u1kMsbQhy7oym1iiOyjUOXqSVReVC0xmXcWAfSS_jfzyRsWRWS5uCwgt4dZtz_4mSg2UpO5IPcg9YJdp3WS33a8D730f2P0gmBuI8NOaRpunngAurRukt3Yu7o719_9IHj5uEMDZjZxDeYr_e20uExAS_uK4A; AccountID=2119323291; AccountID=2119323291; userInfo=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhY2NfaSI6MjExOTMyMzI5MSwiYXVkIjpbImNvbnNvbGUudm9sY2VuZ2luZS5jb20iXSwiZXhwIjoxNzczODQwNDI2LCJpIjoiMzAxZGI5YzMwYjNiMTFmMTkxMmUzNDM2YWMxMjAwMmMiLCJpZF9uIjoiMjA1MOaJi-acuueUqOaItyNvakNPUHUiLCJtc2ciOm51bGwsInBpZCI6IjM5MTBkOWY1LWMwYjYtNGU5OS04ODA0LThlMzJhOTdlYTVhNiIsInNzX24iOiIyMDUw5omL5py655So5oi3I29qQ09QdSIsInQiOiJBY2NvdW50IiwidG9waWMiOiJzaWduaW5fdXNlcl9pbmZvIiwidmVyc2lvbiI6InYxIiwiemlwIjoiIn0.DVAUTdimCRgm22-LovtYJghLyno4eea6P6GG0obifXAfVKh_mVZdNQNZfbhjq8Fg-Y_72MxFT9rnBkpHzDX_XbmK9LQPK66VeY_8pgzFDsBiSvd9-lCz8NhZWB2WOwkRyleb4wvDYkeccuOyUBCw0jdlhKgDEfkTwvzAJwgbeMn0Oo8gf5ewTykNTZGR96QzERAM4czTsawP-GOfOV12OjmGyiJGI4fHt_4F4966y-zR7WjrTKQGiFJlfBO6YrGU2lugHnZR_jk8Lc9fm47yaC0wa2vSFz00BvJXyXOEDfU9kxS099UJ9zG1ATtgEeP3OXrPr0vKzYGjMWLR_a2Mig; csrfToken=7e1563df27ce5e89402a6a8c70e8ec65; csrfToken=7e1563df27ce5e89402a6a8c70e8ec65; user_locale=zh; monitor_session_id=2681371947497439331; __tea_cache_tokens_3569={%22web_id%22:%227592822769650566666%22%2C%22user_unique_id%22:%227592822769650566666%22%2C%22timestamp%22:1771290014810%2C%22_type_%22:%22default%22}"
    # api_key = "volc_platform_clear_user_locale=1; p_c_check=1; vcloudWebId=9e9d3005-3692-4a5a-a46d-1566df974868; user_locale=zh; monitor_huoshan_web_id=8861308256730147452; monitor_session_id_flag=1; volc-design-locale=zh; login_scene=11; volcengineLoginMethod=pwd; __spti=11_000J3JIXW12PtPrMwlQ3ilQxfn2UtC; __sptiho=7F11_000J3JIXW12PtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC; __spti=11_000J3JIXW12PtPrMwlQ3ilQxfn2UtC; __sptiho=7F11_000J3JIXW12PtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC; finance-hub-sdk-lang=zh; i18next=zh; s_v_web_id=verify_ml5bnfec_o579jXU9_eFa6_4ZIz_99Xg_epAghEE6DzaY; ve_doc_history=6256; VOLCFE_im_uuid=1770823408338649820; isIntranet=0; gfkadpd=3569,42874|520918,36088; monitor_session_id=8911131996489492397; monitor_traceid_base_cookie=26; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0NjI4NjcsImlhdCI6MTc3MTI5MDA2NywiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiIyYTA0ZDE3NC1kMTI5LTQzYzAtODYzOS03YjgzMTMwOWJhN2MiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXlNeld5a0RqMSs5d1pOb1hMSUZMSW40dmRNVGs1dnpTdlJPREF0cE9mMktYRXpRMU56WjkxZGorYnMrdjVsQlhQT3JZcmV3UVd1RHJuSzRITjBXSkx6cy9OemMvendxVU1FQUFBLy84RFg2TXdjUUFBQUE9PSIsIm5hbWUiOiI3MTU35omL5py655So5oi3I0hRcEVDbyIsInN1YiI6IjIxMTkzMjY1MjgiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyNjUyODpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.K39YNHuhB3a3EuePcV29Yx8yRsCk0KAwNX-b9OIex-GmqpeRQGTnoXLuSmYBSIY-nI9k-tNDqyGWTvpnx5FR1kZlQjNlNdaow06ZeEiP5Ogi5ANI9DHLmM5VwxN-E865CulUCHSj9XG4WXVgEj8vxkCksTERu4lulpc33a6T1MtRvbc6_GbVnwsUnccWrTIlm24kMctTvFDBnQiuUrH1aeLPe_T9SOLcfJceHv6z8S0RRrDi44dtxvvyJ6mvyWbeSO2myaAPltn4PZqF4lQGDDm2pViJELYVaVUOi657-V2499_3kXd6-pHCadA0YZQL5GzS_uScV2acLSDXV50WCA; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0NjI4NjcsImlhdCI6MTc3MTI5MDA2NywiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiIyYTA0ZDE3NC1kMTI5LTQzYzAtODYzOS03YjgzMTMwOWJhN2MiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXlNeld5a0RqMSs5d1pOb1hMSUZMSW40dmRNVGs1dnpTdlJPREF0cE9mMktYRXpRMU56WjkxZGorYnMrdjVsQlhQT3JZcmV3UVd1RHJuSzRITjBXSkx6cy9OemMvendxVU1FQUFBLy84RFg2TXdjUUFBQUE9PSIsIm5hbWUiOiI3MTU35omL5py655So5oi3I0hRcEVDbyIsInN1YiI6IjIxMTkzMjY1MjgiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyNjUyODpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.K39YNHuhB3a3EuePcV29Yx8yRsCk0KAwNX-b9OIex-GmqpeRQGTnoXLuSmYBSIY-nI9k-tNDqyGWTvpnx5FR1kZlQjNlNdaow06ZeEiP5Ogi5ANI9DHLmM5VwxN-E865CulUCHSj9XG4WXVgEj8vxkCksTERu4lulpc33a6T1MtRvbc6_GbVnwsUnccWrTIlm24kMctTvFDBnQiuUrH1aeLPe_T9SOLcfJceHv6z8S0RRrDi44dtxvvyJ6mvyWbeSO2myaAPltn4PZqF4lQGDDm2pViJELYVaVUOi657-V2499_3kXd6-pHCadA0YZQL5GzS_uScV2acLSDXV50WCA; AccountID=2119326528; AccountID=2119326528; userInfo=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhY2NfaSI6MjExOTMyNjUyOCwiYXVkIjpbImNvbnNvbGUudm9sY2VuZ2luZS5jb20iXSwiZXhwIjoxNzczODgyMDY3LCJpIjoiMjQ3YjRiMDgwYjljMTFmMTkxMWYzNDM2YWMxMjAwOTMiLCJpZF9uIjoiNzE1N-aJi-acuueUqOaItyNIUXBFQ28iLCJtc2ciOm51bGwsInBpZCI6IjJhMDRkMTc0LWQxMjktNDNjMC04NjM5LTdiODMxMzA5YmE3YyIsInNzX24iOiI3MTU35omL5py655So5oi3I0hRcEVDbyIsInQiOiJBY2NvdW50IiwidG9waWMiOiJzaWduaW5fdXNlcl9pbmZvIiwidmVyc2lvbiI6InYxIiwiemlwIjoiIn0.KC5KoPcNYmT-SzqjJ2fvAYDjWcKNvza4kKmXLBpks9iGsxeGL02qmWvGoqu4F8-5N7oOdyDfG99fbCx0X65O2nW7jcei8Rj9bWljKbXpovE4IyyJ54LoNWlv2wRN6ALY7lvC-HIrzxtmz8aTjN4bZuMEVPBko9RBobedvt8i0Lto_6IuBE8FWsb9RNsqKZIAKALXMz3X6SeQQ6DSw8BXUx0dS8SYbdHMQuamVhXBx6DGzJdKlo_sPuHupHphl6LkX55Wnt9H0pVI6NdAShPI4otZg2QOt9vepvdVoP-y-Vk4Mq7d_t7u-97CFdpgDTGfS_3yE8CQSZGVDzKYELbkXg; csrfToken=ec795fe2ed20534a91b5f8ff614cf3a4; csrfToken=ec795fe2ed20534a91b5f8ff614cf3a4; __tea_cache_tokens_3569={%22web_id%22:%227602288869463918123%22%2C%22user_unique_id%22:%227602288869463918123%22%2C%22timestamp%22:1771290077452%2C%22_type_%22:%22default%22}; monitor_tracing_cookie=[]; user_locale=zh"
    # api_key = "volc_platform_clear_user_locale=1; p_c_check=1; vcloudWebId=c521e550-d06c-45f1-9285-4fbe8342eb89; user_locale=zh; monitor_huoshan_web_id=6202964249524884595; monitor_session_id_flag=1; volc-design-locale=zh; VOLCFE_im_uuid=1771005318779470069; login_scene=11; volcengineLoginMethod=pwd; i18next=zh; s_v_web_id=verify_mll6uvlz_MUc2o4xZ_44Xz_4xtY_9XHk_5xnWBhV8jRTv; __spti=11_000J3dBxOXvPtPrMwlQ3ilQxfn2UtC; __sptiho=4F11_000J3dBxOXvPtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC; __spti=11_000J3dBxOXvPtPrMwlQ3ilQxfn2UtC; __sptiho=4F11_000J3dBxOXvPtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC; finance-hub-sdk-lang=zh; monitor_traceid_base_cookie=10; verify_mll6uvlz_MUc2o4xZ_44Xz_4xtY_9XHk_5xnWBhV8jRTv=1; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0MDg4MTYsImlhdCI6MTc3MTIzNjAxNiwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiIzYmQ2NTIwMy0wNmIwLTRjNWItYjRiZi1lNmNiM2Y1YjVmNWIiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXlNTEV3bFZoMDlmUVpOb1VOSUZMSW40dmRNVGs1dnpTdlJHQnArOGxQN0ZMaVppWW1Gczg2dTUvTjJmVjh5b3BuSGR1VncxTktLLzJDbGNEbWFMRWw1K2ZtNXVkNTRWSUdDQUFBLy85bkFUM2tjUUFBQUE9PSIsIm5hbWUiOiI2NDQ45omL5py655So5oi3I1dkdXlOUyIsInN1YiI6IjIxMTkzMjA0ODUiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyMDQ4NTpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.pW2ZTlCa_Fq6cQIpSqwuejH_kzBFFoqrcruqSJKInSVjTEZ86L2lg4Qc_ABpz_rMI6SDmF0RDI8xJutd4Za_gVxJAtwBDwLsesGu37XVIh1ubrgc76MIU3llDGMYU2AX1PVa6WzFUIWG7VvTKzhy6mPhIvGLnrpM02Iq4rnTMkhQwtaoQ1jL6tgU4urBuAWEmMBWSiaf74CPa_V47CGrUwQSNAIWHdzOkw4eMS06ErOetE9phQS23dClW5Fj1ENXiMY39ZbVHixhEIysAXLB6OYAIVPWR-YRuWxLNqezaxELAA7vN1NupH6T6rJaF1tVeCX5tV50fG9RTGV23NJQGA; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0MDg4MTYsImlhdCI6MTc3MTIzNjAxNiwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiIzYmQ2NTIwMy0wNmIwLTRjNWItYjRiZi1lNmNiM2Y1YjVmNWIiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXlNTEV3bFZoMDlmUVpOb1VOSUZMSW40dmRNVGs1dnpTdlJHQnArOGxQN0ZMaVppWW1Gczg2dTUvTjJmVjh5b3BuSGR1VncxTktLLzJDbGNEbWFMRWw1K2ZtNXVkNTRWSUdDQUFBLy85bkFUM2tjUUFBQUE9PSIsIm5hbWUiOiI2NDQ45omL5py655So5oi3I1dkdXlOUyIsInN1YiI6IjIxMTkzMjA0ODUiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyMDQ4NTpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.pW2ZTlCa_Fq6cQIpSqwuejH_kzBFFoqrcruqSJKInSVjTEZ86L2lg4Qc_ABpz_rMI6SDmF0RDI8xJutd4Za_gVxJAtwBDwLsesGu37XVIh1ubrgc76MIU3llDGMYU2AX1PVa6WzFUIWG7VvTKzhy6mPhIvGLnrpM02Iq4rnTMkhQwtaoQ1jL6tgU4urBuAWEmMBWSiaf74CPa_V47CGrUwQSNAIWHdzOkw4eMS06ErOetE9phQS23dClW5Fj1ENXiMY39ZbVHixhEIysAXLB6OYAIVPWR-YRuWxLNqezaxELAA7vN1NupH6T6rJaF1tVeCX5tV50fG9RTGV23NJQGA; AccountID=2119320485; AccountID=2119320485; userInfo=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhY2NfaSI6MjExOTMyMDQ4NSwiYXVkIjpbImNvbnNvbGUudm9sY2VuZ2luZS5jb20iXSwiZXhwIjoxNzczODI4MDE2LCJpIjoiNGI3ZDFiNDYwYjFlMTFmMThjODEzNDM2YWMxMjAwYmEiLCJpZF9uIjoiNjQ0OOaJi-acuueUqOaItyNXZHV5TlMiLCJtc2ciOm51bGwsInBpZCI6IjNiZDY1MjAzLTA2YjAtNGM1Yi1iNGJmLWU2Y2IzZjViNWY1YiIsInNzX24iOiI2NDQ45omL5py655So5oi3I1dkdXlOUyIsInQiOiJBY2NvdW50IiwidG9waWMiOiJzaWduaW5fdXNlcl9pbmZvIiwidmVyc2lvbiI6InYxIiwiemlwIjoiIn0.VbEAGzkk-FLo2PXmEW6jh5Tcrh6q7eVnGRlmxa4qvFTDbRcmIEmbOTVJGup4LSexuu0v_Y3JsCshjxQVSEES1uZmp-qVXfwI2_zTq6yu3SYX5Js3vpMRrw36WSMBD36TghWVqTAax-ALBih77z5CtYD_yHWX0Yn0asfJiylKI0pU4yt7J64Kp7fYpik2gfJ7mxvMdOh0TeFvIrA2Mr3SD-h9d4PzyHCmS0m1ZXTrG_CPwD99NRtfyTQzVBAp-2RWygpeFHbMs4AVOFabRambhSzPgbINbFjH83-aicxou2E8B_TYTh_FgF2rJRtLoxUxaI9TWciQsbVGEIldGIO2CA; csrfToken=efa716117f55d3d0d8e463144bb60002; csrfToken=efa716117f55d3d0d8e463144bb60002; user_locale=zh; monitor_session_id=3901360513443069761; gfkadpd=520918,36088; __tea_cache_tokens_3569={%22web_id%22:%227606409831347963446%22%2C%22user_unique_id%22:%227606409831347963446%22%2C%22timestamp%22:1771290195689%2C%22_type_%22:%22default%22}; isIntranet=0"
    # api_key = "vcloudWebId=3fcbbdec-544f-4461-b011-2f4ce5975226; monitor_huoshan_web_id=3008705476903245653; monitor_session_id_flag=1; connect.sid=s%3A5c6ee92a-160f-4b25-ad10-ed020f92fe63.b0dZAoRdGD9CsOKAkZnZbAbTNRC4mI8iS8gK7f4FXOg; i18next=zh; volc-design-locale=zh; volc_platform_clear_user_locale=1; p_c_check=1; user_locale=zh; VOLCFE_im_uuid=1770961658125265474; login_scene=11; volcengineLoginMethod=pwd; s_v_web_id=verify_mlkgv81y_TNdGh1ix_oYwk_4BEW_9z8o_WWA67980aaon; finance-hub-sdk-lang=zh; __spti=11_000J39h6g7wPtPrMwlQ3ilQxfn2UtC; __sptiho=3011_000J39h6g7wPtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC; __spti=11_000J39h6g7wPtPrMwlQ3ilQxfn2UtC; __sptiho=3011_000J39h6g7wPtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC; isIntranet=0; verify_mlkgv81y_TNdGh1ix_oYwk_4BEW_9z8o_WWA67980aaon=1; gfkadpd=3569,42874|520918,36088; monitor_session_id=4873312648011786125; monitor_traceid_base_cookie=7; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0NjMxMzksImlhdCI6MTc3MTI5MDMzOSwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiI3OTEwMjE4Yy1hMDQwLTQwMWEtODQyZi00ZTZhNTQxNjAwMmIiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXlNek96a0xqejk5d1pOb1VuSUZMSW40dmRNVGs1dnpTdlJPRE05cE9mMktYRUxVeE1ESjkxZGorYnMrdjVsQlhQT3JZckJ3YVh1ZVU2S29ITjBXSkx6cy9OemMvendxVU1FQUFBLy8rRllIanFjUUFBQUE9PSIsIm5hbWUiOiI4NDQx5omL5py655So5oi3I1FTdkZtQSIsInN1YiI6IjIxMTkzMjY2NjgiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyNjY2ODpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.DdxFD-ST5QXhA_qZtDwvAphUCW4ar7cKBxv54OPqi1Ekl--vxW7zRzWtPFO2tSQVTM-SLW8bd6MVmV5apGwqRYSCwj72VvcxLyjra0lf4OGJwIm2EZf0-G0zHGumFzZSEEqu0eOpA4mACCIZD61fM0SfPYa4usZ2El8EfV2yRG2P6KlexefvA-RYI01MOayqvC-r8VAqSKzmw8US7CxR0x7HMzryzrv-jytbVp7SCysWP_Y3IiIzhmZ93BpwnYvosJm-qaHvuiuezlG2GVL-GySa-MAAh1LdxqB7r6GrfX9z-hUqXimLK3PqXXXaoVgH6S1vgYKK-vyF9FfbVfatxA; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0NjMxMzksImlhdCI6MTc3MTI5MDMzOSwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiI3OTEwMjE4Yy1hMDQwLTQwMWEtODQyZi00ZTZhNTQxNjAwMmIiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTME5EWXlNek96a0xqejk5d1pOb1VuSUZMSW40dmRNVGs1dnpTdlJPRE05cE9mMktYRUxVeE1ESjkxZGorYnMrdjVsQlhQT3JZckJ3YVh1ZVU2S29ITjBXSkx6cy9OemMvendxVU1FQUFBLy8rRllIanFjUUFBQUE9PSIsIm5hbWUiOiI4NDQx5omL5py655So5oi3I1FTdkZtQSIsInN1YiI6IjIxMTkzMjY2NjgiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjExOTMyNjY2ODpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.DdxFD-ST5QXhA_qZtDwvAphUCW4ar7cKBxv54OPqi1Ekl--vxW7zRzWtPFO2tSQVTM-SLW8bd6MVmV5apGwqRYSCwj72VvcxLyjra0lf4OGJwIm2EZf0-G0zHGumFzZSEEqu0eOpA4mACCIZD61fM0SfPYa4usZ2El8EfV2yRG2P6KlexefvA-RYI01MOayqvC-r8VAqSKzmw8US7CxR0x7HMzryzrv-jytbVp7SCysWP_Y3IiIzhmZ93BpwnYvosJm-qaHvuiuezlG2GVL-GySa-MAAh1LdxqB7r6GrfX9z-hUqXimLK3PqXXXaoVgH6S1vgYKK-vyF9FfbVfatxA; AccountID=2119326668; AccountID=2119326668; userInfo=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhY2NfaSI6MjExOTMyNjY2OCwiYXVkIjpbImNvbnNvbGUudm9sY2VuZ2luZS5jb20iXSwiZXhwIjoxNzczODgyMzM5LCJpIjoiYzZhOGJmMzUwYjljMTFmMWI3NDczNDM2YWMxMjAyMzkiLCJpZF9uIjoiODQ0MeaJi-acuueUqOaItyNRU3ZGbUEiLCJtc2ciOm51bGwsInBpZCI6Ijc5MTAyMThjLWEwNDAtNDAxYS04NDJmLTRlNmE1NDE2MDAyYiIsInNzX24iOiI4NDQx5omL5py655So5oi3I1FTdkZtQSIsInQiOiJBY2NvdW50IiwidG9waWMiOiJzaWduaW5fdXNlcl9pbmZvIiwidmVyc2lvbiI6InYxIiwiemlwIjoiIn0.RkA8KrXDpBjojBYdyv4REn077bKYpKKJtbquhR1s3vRaexIV-lmMZKxLsOhMbSuw_45LBrcFSoZvGijoKoWlhLXGGv-uCGQgfW-Wbt9SKrSk9ba2n5WUrAqYbzQ5CNbPvGFp1BXXNj8vHpy2ddMI3lAgDDQZLace1EFdmtsKyS-3J8zPb6chpIXlE-N7UwtGuv2f-Fp1pzWHoP0sHIefZ7ng4xhERTNA8jkNzUkDkG5pDFWn7h1FdI_P2AkwIZ6_R9nO6xqXykLkNVV0M-CVFgtPiiPgNVbGQ3W_Pne6R_18ObaWfKnLNPQS_nQdxDFCVMZ7XKwB_NS3XMZby5VPLg; csrfToken=1f85e2178436c1f7e08c5d74a4671df5; csrfToken=1f85e2178436c1f7e08c5d74a4671df5; __tea_cache_tokens_3569={%22web_id%22:%227606222317316736522%22%2C%22user_unique_id%22:%227606222317316736522%22%2C%22timestamp%22:1771290341103%2C%22_type_%22:%22default%22}"
    # api_key = "monitor_huoshan_web_id=1103721958171764557; i18next=zh; volcfe-uuid=fa216a73-440b-4276-948a-428ebf17bf5b; connect.sid=s%3A1a0e396c-53bc-483f-9dcb-505a17592539.zbX3SGrTAcR9I5%2BKZCIfouz%2B1YH1Ih9fnEtsViMLSAk; connect.sid=s%3A1a0e396c-53bc-483f-9dcb-505a17592539.zbX3SGrTAcR9I5%2BKZCIfouz%2B1YH1Ih9fnEtsViMLSAk; volc_platform_clear_user_locale=1; p_c_check=1; vcloudWebId=794ce10e-a200-4010-aaa2-9463cb09b0f6; user_locale=zh; monitor_session_id_flag=1; volc-design-locale=zh; isIntranet=0; s_v_web_id=verify_mllorwgx_iDQfRmNw_icyg_42mA_9O5h_5Y5wyImZCbO4; VOLCFE_im_uuid=1771035442133049694; login_scene=11; volcengineLoginMethod=pwd; monitor_session_id=4122801852251178612; monitor_traceid_base_cookie=2; verify_mllorwgx_iDQfRmNw_icyg_42mA_9O5h_5Y5wyImZCbO4=1; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0NjY3MTMsImlhdCI6MTc3MTI5MzkxMywiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiIyM2RjNmQ0Ny00NjI5LTRmZGItYTllNi02NDlmYTA3ODM5YmEiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpRd3REQTNNek14a3pndzgvd1pOb1ZiSUZMSWtJdmRNVGs1dnpTdlJHRForZ1d2MktVNGNncU16RTFNRFN5VndCcTEySkx6YzNQejg3emc0b0FBQUFELy93bkVpalJUQUFBQSIsIm5hbWUiOiJscDI3NDUwOSIsInN1YiI6IjIxMDE4NzY2NDYiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjEwMTg3NjY0Njpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.T4j8_wAGchudG4wvU_lzmu2qwJ4SXhNbqWkR0l0GFwslQsPMPkPJ28AzTeLQGu-_wS7cA4RlUQc5U06qbWDJ7M5y-IPxi95m12J6_PvmvX4JkQC4OTpwAKSj9ySahhEQxyPCL8-cWRMw0xITecITDDD4kvfYpKhf95cMj58hTx-8XLgt0NdxXPUKjWF91H3K2sk9mzDwvEynCpgvuAzspJjZYqMHuzYANl2OVAV6WRVAVvr4PL0KkJ3isNmiwjI-rGfexNW-ky8pJ6M7OrJviGdJnEmsIYd1GWDUl3srxrfZ5jmHIEqvGnQsUdOOz7XuDzpJx0bAbT3uvE6cTaUr7Q; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzE0NjY3MTMsImlhdCI6MTc3MTI5MzkxMywiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiIyM2RjNmQ0Ny00NjI5LTRmZGItYTllNi02NDlmYTA3ODM5YmEiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpRd3REQTNNek14a3pndzgvd1pOb1ZiSUZMSWtJdmRNVGs1dnpTdlJHRForZ1d2MktVNGNncU16RTFNRFN5VndCcTEySkx6YzNQejg3emc0b0FBQUFELy93bkVpalJUQUFBQSIsIm5hbWUiOiJscDI3NDUwOSIsInN1YiI6IjIxMDE4NzY2NDYiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjEwMTg3NjY0Njpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.T4j8_wAGchudG4wvU_lzmu2qwJ4SXhNbqWkR0l0GFwslQsPMPkPJ28AzTeLQGu-_wS7cA4RlUQc5U06qbWDJ7M5y-IPxi95m12J6_PvmvX4JkQC4OTpwAKSj9ySahhEQxyPCL8-cWRMw0xITecITDDD4kvfYpKhf95cMj58hTx-8XLgt0NdxXPUKjWF91H3K2sk9mzDwvEynCpgvuAzspJjZYqMHuzYANl2OVAV6WRVAVvr4PL0KkJ3isNmiwjI-rGfexNW-ky8pJ6M7OrJviGdJnEmsIYd1GWDUl3srxrfZ5jmHIEqvGnQsUdOOz7XuDzpJx0bAbT3uvE6cTaUr7Q; AccountID=2101876646; AccountID=2101876646; userInfo=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhY2NfaSI6MjEwMTg3NjY0NiwiYXVkIjpbImNvbnNvbGUudm9sY2VuZ2luZS5jb20iXSwiZXhwIjoxNzczODg1OTEzLCJpIjoiMThmNzAxNzgwYmE1MTFmMWIwNWIzNDM2YWMxMjAwYWMiLCJpZF9uIjoibHAyNzQ1MDkiLCJtc2ciOm51bGwsInBpZCI6IjIzZGM2ZDQ3LTQ2MjktNGZkYi1hOWU2LTY0OWZhMDc4MzliYSIsInNzX24iOiJscDI3NDUwOSIsInQiOiJBY2NvdW50IiwidG9waWMiOiJzaWduaW5fdXNlcl9pbmZvIiwidmVyc2lvbiI6InYxIiwiemlwIjoiIn0.uq9rQyk7dZJXOp-NyO_FdugJZK9CAxYZl7nvMV1FWWmpRz-JCBaHF3rtUOG5QEuqKsp2MfO48rtjtLxfFG4x66_6lEtg2YT5tU0BDJEEWmMou7FvRwEQiOv-U2NvBKH7nvd0v_pnfvnEf7qsdLJHPgcR1PJbNYEmoiefgKxOnNpSLv5JL47LoNrUJiP5p6PKIu8DtqYAO0bdCDBCiJ-M2hGw2SeZ6cn0BbGPay3VUuHrboO-3tXtivHQo8Wsnj_vcSMqHCB4x7SZ0pldlFb1-tEHPfRf3Tul8ZRbXVvXmQkEivOyqr-Kv3QTiwO_EQNQcwynqLWkrqW_m-4ZK9GdzQ; csrfToken=c2ea67b9cb6f94dd006a144b8d368eaf; csrfToken=c2ea67b9cb6f94dd006a144b8d368eaf; monitor_tracing_cookie=[]; finance-hub-sdk-lang=zh; user_locale=zh; gfkadpd=3569,42874|520918,36088; __tea_cache_tokens_3569={%22web_id%22:%227606539240382678591%22%2C%22user_unique_id%22:%227606539240382678591%22%2C%22timestamp%22:1771293926322%2C%22_type_%22:%22default%22}"
    async def main(n=1):
        for i in range(n):
            await get(None, api_key=api_key)
            i and await asyncio.sleep(60)


    arun(main())


    # arun(main(100))

    async def cmain(n=1):
        for i in range(n):
            await create(api_key, task_ids=None)
            i and await asyncio.sleep(30)

    # arun(create(api_key, task_ids=None))
    # arun(cmain(100))
    # task_ids = ["delay::gcShgzK6GYhXyRyih5P2VZ", "delay::8xEN8ag3AGb6UYUy6cRGci"]
    # arun(get(task_ids, api_key=api_key))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : formdata_images
# @Time         : 2026/2/14 23:17
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from meutils.pipe import *
from openai import AsyncOpenAI
from meutils.schemas.image_types import ImageRequest, ImagesResponse

"""

curl https://ai.gitee.com/v1/images/mattings \
	-X POST \
	-H "X-Failover-Enabled: true" \
	-H "Authorization: Bearer XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX" \
	-F "image=@path/to/image.webp" \
	-F "model=RMBG-2.0"
	
files = [
        ('file', file_bytes),
        ('security', (None, 'true')),
        ('type', (None, 'image')),
        ('modelName', (None, 'doubao-seedance-2-0')),
        ('modelVersion', (None, '260128')),
        ('biz', (None, 'experience_video')),
    ]

extra_headers = {
    "Content-Type": "multipart/form-data",
    "cookie": api_key
}
client = AsyncOpenAI(base_url=base_url, default_headers=extra_headers)
response = await client.post("/UploadArkTosFile", files=files, cast_to=object)

"""

BASE_URL = "https://ai.gitee.com/v1"


async def generate(request: ImageRequest, api_key: Optional[str] = None):
    # reuqest.image
    if isinstance(request.image, list):
        request.image = request.image[0]

    files = [
        ('model', (None, request.model)),
        ('response_format', (None, request.response_format)),
        # ('image', await to_bytes(request.image)),
        # ('image', (None, request.image)),
    ]
    if request.image.startswith("http"):
        files.append(('image', (None, request.image)))

    default_headers = {
        "X-Failover-Enabled": "true",
        "Content-Type": "multipart/form-data",
    }
    client = AsyncOpenAI(base_url=BASE_URL, api_key=api_key, default_headers=default_headers)

    response = await client.post(
        "/images/mattings",
        files=files,
        cast_to=object
    )

    return response


if __name__ == '__main__':
    api_key = os.getenv("GITEE_API_KEY")
    request = ImageRequest(
        model="RMBG-2.0",
        # image="http://mxrnetfiles.oss-cn-beijing.aliyuncs.com/AI_IMAGE/773920428888133.jpeg"
        image = "https://s3.ffire.cc/files/jimeng.jpg"
    )

    _ = arun(generate(request, api_key=api_key))
